Zuul - A Project Gating System
==============================

Zuul is a program that drives continuous integration, delivery, and
deployment systems with a focus on project gating and interrelated
projects.

If you are looking for the Edge routing service named Zuul that is
related to Netflix, it can be found here:
https://github.com/Netflix/zuul

If you are looking for the Javascript testing tool named Zuul, it
can be found here:
https://github.com/defunctzombie/zuul

Documentation
-------------

Zuul Users
**********

.. toctree::
   :maxdepth: 2

   tutorials/user
   howtos/user
   reference/user

Zuul Admins
***********

.. toctree::
   :maxdepth: 2

   tutorials/admin
   howtos/admin
   reference/admin

Digging Deeper
**************

.. toctree::
   :maxdepth: 2

   discussion/index

.. toctree::
   :maxdepth: 2

   reference/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

